@@ -41,9 +41,10 @@ class Easyocrpipleline:
             dictionary[result[i][1]]["score"] = result[i][2]
         json_name = file.split('/')[-1].split('.')[0]
         # json log file create
-        print("log/"+json_name,'+++++++++++++++++++')
-        with open("/tmp/"+json_name+".json", "w") as outfile:
+        print("/tmp/"+json_name,'+++++++++++++++++++')
+        with open("/tmp"+json_name+".json", "w") as outfile:
             json.dump(dictionary, outfile)
+        print("_+_+__+_+_+")
 
     def image_process(self, path):
         """
